@@ -10,11 +10,12 @@ logger = getLogger(__name__)
 
 
 class GaussianBlurFilter(Filter):
-    def __init__(self, debug: bool = False) -> None:
+    def __init__(self, size: int = 7, debug: bool = False) -> None:
+        self.size = size
         self.debug = debug
 
     def eval(self, image: np.ndarray) -> np.ndarray:
-        logger.debug("Applying 'GaussianBlurFilter'...")
-        blurred_image = cv2.GaussianBlur(image, (7, 7), 0)
+        logger.debug(f"Applying 'GaussianBlurFilter' with size {self.size}...")
+        blurred_image = cv2.GaussianBlur(image, (self.size, self.size), 0)
         debug_show(blurred_image, debug=self.debug)
         return blurred_image
